@@ -4,7 +4,7 @@ use std::error::Error;
 use std::time::Duration;
 use tokio::time;
 
-const CAMERA_NAME: &'static str = "A:5BA2429F";
+const CAMERA_NAME: &'static str = "A:4BE2529F";
 
 #[tokio::main]
 async fn main() -> Result<(), Box<dyn Error>> {
@@ -14,12 +14,20 @@ async fn main() -> Result<(), Box<dyn Error>> {
     //Connect with a set timeout
     camera.connect(Duration::from_secs(10)).await.unwrap();
 
+    dbg!("connected");
+
+    time::sleep(Duration::from_secs(5)).await;
+
+    time::sleep(Duration::from_secs(5)).await;
+
     //Change the ISO to 320
     camera
-        .write(255, Operation::AssignValue, Command::Video(Video::Iso(640)))
+        .write(255, Operation::AssignValue, Command::Video(Video::Iso(320)))
         .await
         .unwrap();
 
+    dbg!("i am past");
+
     //Subscribe to updates from the camera;
     let mut updates = camera.updates().await;
 
